@@ -21,42 +21,62 @@
 #include <QDBusConnectionInterface>
 #include <QDBusMessage>
 #include <QDBusVariant>
+#include <QDebug>
 
 AccountsServiceDBusAdaptor::AccountsServiceDBusAdaptor(QObject* parent)
   : QObject(parent),
     m_accountsManager(nullptr),
-    m_users()
+    m_ignoreNextChanged(false)
 {
     QDBusConnection connection = QDBusConnection::SM_BUSNAME();
     QDBusConnectionInterface *interface = connection.interface();
-    interface->startService("org.freedesktop.Accounts");
-    m_accountsManager = new QDBusInterface("org.freedesktop.Accounts",
-                                          "/org/freedesktop/Accounts",
-                                          "org.freedesktop.Accounts",
-                                          connection, this);
+    interface->startService(QStringLiteral("org.freedesktop.Accounts"));
+    m_accountsManager = new QDBusInterface(QStringLiteral("org.freedesktop.Accounts"),
+                                           QStringLiteral("/org/freedesktop/Accounts"),
+                                           QStringLiteral("org.freedesktop.Accounts"),
+                                           connection, this);
 }
 
 QVariant AccountsServiceDBusAdaptor::getUserProperty(const QString &user, const QString &interface, const QString &property)
 {
     QDBusInterface *iface = getUserInterface(user);
     if (iface != nullptr && iface->isValid()) {
-        QDBusMessage answer = iface->call("Get", interface, property);
-        if (answer.type() == QDBusMessage::ReplyMessage) {
-            return answer.arguments()[0].value<QDBusVariant>().variant();
+        QDBusReply<QVariant> answer = iface->call(QStringLiteral("Get"), interface, property);
+        if (answer.isValid()) {
+            return answer;
         }
     }
     return QVariant();
 }
 
+QDBusPendingReply<QVariant> AccountsServiceDBusAdaptor::getUserPropertyAsync(const QString &user, const QString &interface, const QString &property)
+{
+    QDBusInterface *iface = getUserInterface(user);
+    if (iface != nullptr && iface->isValid()) {
+        return iface->asyncCall(QStringLiteral("Get"), interface, property);
+    }
+    return QDBusPendingReply<QVariant>(QDBusMessage::createError(QDBusError::Other, QStringLiteral("Invalid Interface")));
+}
+
 void AccountsServiceDBusAdaptor::setUserProperty(const QString &user, const QString &interface, const QString &property, const QVariant &value)
 {
     QDBusInterface *iface = getUserInterface(user);
     if (iface != nullptr && iface->isValid()) {
         // The value needs to be carefully wrapped
-        iface->call("Set", interface, property, QVariant::fromValue(QDBusVariant(value)));
+        iface->call(QStringLiteral("Set"), interface, property, QVariant::fromValue(QDBusVariant(value)));
     }
 }
 
+QDBusPendingCall AccountsServiceDBusAdaptor::setUserPropertyAsync(const QString &user, const QString &interface, const QString &property, const QVariant &value)
+{
+    QDBusInterface *iface = getUserInterface(user);
+    if (iface != nullptr && iface->isValid()) {
+        // The value needs to be carefully wrapped
+        return iface->asyncCall(QStringLiteral("Set"), interface, property, QVariant::fromValue(QDBusVariant(value)));
+    }
+    return QDBusPendingCall::fromCompletedCall(QDBusMessage::createError(QDBusError::Other, QStringLiteral("Invalid Interface")));
+}
+
 void AccountsServiceDBusAdaptor::propertiesChangedSlot(const QString &interface, const QVariantMap &changed, const QStringList &invalid)
 {
     // Merge changed and invalidated together
@@ -66,11 +86,19 @@ void AccountsServiceDBusAdaptor::propertiesChangedSlot(const QString &interface,
     combined.removeDuplicates();
 
     Q_EMIT propertiesChanged(getUserForPath(message().path()), interface, combined);
+
+    // In case a non-builtin property changes, we're getting propertiesChanged *and* changed
+    // As the generic changed requires asking back over DBus, it's quite slow to process.
+    // We don't want to trigger that when we know it's not a built-in property change.
+    m_ignoreNextChanged = true;
 }
 
 void AccountsServiceDBusAdaptor::maybeChangedSlot()
 {
-    Q_EMIT maybeChanged(getUserForPath(message().path()));
+    if (!m_ignoreNextChanged) {
+        Q_EMIT maybeChanged(getUserForPath(message().path()));
+    }
+    m_ignoreNextChanged = false;
 }
 
 QString AccountsServiceDBusAdaptor::getUserForPath(const QString &path)
@@ -88,13 +116,13 @@ QDBusInterface *AccountsServiceDBusAdaptor::getUserInterface(const QString &user
 {
     QDBusInterface *iface = m_users.value(user);
     if (iface == nullptr && m_accountsManager->isValid()) {
-        QDBusMessage answer = m_accountsManager->call("FindUserByName", user);
-        if (answer.type() == QDBusMessage::ReplyMessage) {
-            QString path = answer.arguments()[0].value<QDBusObjectPath>().path();
+        QDBusReply<QDBusObjectPath> answer = m_accountsManager->asyncCall(QStringLiteral("FindUserByName"), user);
+        if (answer.isValid()) {
+            const QString path = answer.value().path();
 
-            iface = new QDBusInterface("org.freedesktop.Accounts",
+            iface = new QDBusInterface(QStringLiteral("org.freedesktop.Accounts"),
                                        path,
-                                       "org.freedesktop.DBus.Properties",
+                                       QStringLiteral("org.freedesktop.DBus.Properties"),
                                        m_accountsManager->connection(), this);
 
             // With its own pre-defined properties, AccountsService is oddly
@@ -104,8 +132,8 @@ QDBusInterface *AccountsServiceDBusAdaptor::getUserInterface(const QString &user
             iface->connection().connect(
                 iface->service(),
                 path,
-                "org.freedesktop.Accounts.User",
-                "Changed",
+                QStringLiteral("org.freedesktop.Accounts.User"),
+                QStringLiteral("Changed"),
                 this,
                 SLOT(maybeChangedSlot()));
 
@@ -114,12 +142,14 @@ QDBusInterface *AccountsServiceDBusAdaptor::getUserInterface(const QString &user
             iface->connection().connect(
                 iface->service(),
                 path,
-                "org.freedesktop.DBus.Properties",
-                "PropertiesChanged",
+                QStringLiteral("org.freedesktop.DBus.Properties"),
+                QStringLiteral("PropertiesChanged"),
                 this,
                 SLOT(propertiesChangedSlot(QString, QVariantMap, QStringList)));
 
             m_users.insert(user, iface);
+        } else {
+            qWarning() << "Couldn't get user interface" << answer.error().name() << answer.error().message();
         }
     }
     return iface;
