@@ -16,6 +16,9 @@
 
 .pragma library
 
+// %1 is the template["card-background"] string
+// %2 is the template["card-background"]["elements"][0]
+// %3 is the template["card-background"]["elements"][1]
 var kBackgroundLoaderCode = 'Loader {\n\
                                 id: backgroundLoader; \n\
                                 objectName: "backgroundLoader"; \n\
@@ -34,18 +37,14 @@ var kBackgroundLoaderCode = 'Loader {\n\
                                         objectName: "backgroundImage"; \n\
                                         source: { \n\
                                             if (cardData && typeof cardData["background"] === "string") return cardData["background"]; \n\
-                                            else if (template && typeof template["card-background"] === "string") return template["card-background"]; \n\
-                                            else return ""; \n\
+                                            else return "%1"; \n\
                                         } \n\
                                     } \n\
                                     function getColor(index) { \n\
                                         if (cardData && typeof cardData["background"] === "object" \n\
                                             && (cardData["background"]["type"] === "color" || cardData["background"]["type"] === "gradient")) { \n\
                                             return cardData["background"]["elements"][index]; \n\
-                                        } else if (template && typeof template["card-background"] === "object" \n\
-                                                && (template["card-background"]["type"] === "color" || template["card-background"]["type"] === "gradient"))  { \n\
-                                            return template["card-background"]["elements"][index]; \n\
-                                        } else return undefined; \n\
+                                        } else return index === 0 ? %2 : %3; \n\
                                     } \n\
                                 } \n\
                             }\n';
@@ -64,11 +63,28 @@ var kArtShapeHolderCode = 'Item  { \n\
                                 active: cardData && cardData["art"] || false; \n\
                                 asynchronous: root.asynchronous; \n\
                                 visible: status == Loader.Ready; \n\
-                                sourceComponent: UbuntuShape { \n\
+                                sourceComponent: Item { \n\
                                     id: artShape; \n\
                                     objectName: "artShape"; \n\
-                                    radius: "medium"; \n\
+                                    property bool doShapeItem: components["art"]["conciergeMode"] !== true; \n\
                                     visible: image.status == Image.Ready; \n\
+                                    readonly property alias image: artImage; \n\
+                                    property alias borderSource: artShapeShape.borderSource; \n\
+                                    ShaderEffectSource { \n\
+                                        id: artShapeSource; \n\
+                                        sourceItem: artImage; \n\
+                                        anchors.centerIn: parent; \n\
+                                        width: 1; \n\
+                                        height: 1; \n\
+                                        hideSource: doShapeItem; \n\
+                                    } \n\
+                                    Shape { \n\
+                                        id: artShapeShape; \n\
+                                        image: artShapeSource; \n\
+                                        anchors.fill: parent; \n\
+                                        visible: doShapeItem; \n\
+                                        radius: "medium"; \n\
+                                    } \n\
                                     readonly property real fixedArtShapeSizeAspect: (root.fixedArtShapeSize.height > 0 && root.fixedArtShapeSize.width > 0) ? root.fixedArtShapeSize.width / root.fixedArtShapeSize.height : -1; \n\
                                     readonly property real aspect: fixedArtShapeSizeAspect > 0 ? fixedArtShapeSizeAspect : components !== undefined ? components["art"]["aspect-ratio"] : 1; \n\
                                     Component.onCompleted: { updateWidthHeightBindings(); if (artShapeBorderSource !== undefined) borderSource = artShapeBorderSource; } \n\
@@ -87,11 +103,9 @@ var kArtShapeHolderCode = 'Item  { \n\
                                         objectName: "artImage"; \n\
                                         source: cardData && cardData["art"] || ""; \n\
                                         asynchronous: root.asynchronous; \n\
-                                        visible: false; \n\
                                         width: %2; \n\
                                         height: %3; \n\
                                     } \n\
-                                    image: artImage.image; \n\
                                 } \n\
                             } \n\
                         }\n';
@@ -141,7 +155,7 @@ var kOverlayLoaderCode = 'Loader { \n\
 
 // multiple row version of HeaderRowCode
 function kHeaderRowCodeGenerator() {
-var kHeaderRowCodeTemplate = 'Row { \n\
+    var kHeaderRowCodeTemplate = 'Row { \n\
                         id: row; \n\
                         objectName: "outerRow"; \n\
                         property real margins: units.gu(1); \n\
@@ -181,11 +195,11 @@ var kMascotShapeLoaderCode = 'Loader { \n\
                                 id: mascotShapeLoader; \n\
                                 objectName: "mascotShapeLoader"; \n\
                                 asynchronous: root.asynchronous; \n\
-                                active: mascotImage.image.status === Image.Ready; \n\
+                                active: mascotImage.status === Image.Ready; \n\
                                 visible: showHeader && active && status == Loader.Ready; \n\
                                 width: units.gu(6); \n\
                                 height: units.gu(5.625); \n\
-                                sourceComponent: UbuntuShape { image: mascotImage.image } \n\
+                                sourceComponent: UbuntuShape { image: mascotImage } \n\
                                 anchors { %1 } \n\
                             }\n';
 
@@ -206,6 +220,7 @@ var kMascotImageCode = 'CroppedImageMinimumSourceSize { \n\
 // %1 is used as anchors of titleLabel
 // %2 is used as color of titleLabel
 // %3 is used as extra condition for visible of titleLabel
+// %4 is used as title width
 var kTitleLabelCode = 'Label { \n\
                         id: titleLabel; \n\
                         objectName: "titleLabel"; \n\
@@ -217,6 +232,7 @@ var kTitleLabelCode = 'Label { \n\
                         font.pixelSize: Math.round(FontUtils.sizeToPixels(fontSize) * fontScale); \n\
                         color: %2; \n\
                         visible: showHeader %3; \n\
+                        width: %4; \n\
                         text: root.title; \n\
                         font.weight: cardData && cardData["subtitle"] ? Font.DemiBold : Font.Normal; \n\
                         horizontalAlignment: root.titleAlignment; \n\
@@ -232,7 +248,7 @@ var kEmblemIconCode = 'Icon { \n\
                             anchors { \n\
                                 bottom: titleLabel.baseline; \n\
                                 right: parent.right; \n\
-                                %1
+                                %1 \n\
                             } \n\
                             source: cardData && cardData["emblem"] || ""; \n\
                             color: %2; \n\
@@ -302,9 +318,11 @@ var kSummaryLabelCode = 'Label { \n\
 
 function cardString(template, components) {
     var code;
+
+    var templateInteractive = (template == null ? true : (template["non-interactive"] !== undefined ? !template["non-interactive"] : true)) ? "true" : "false";
+
     code = 'AbstractButton { \n\
                 id: root; \n\
-                property var template; \n\
                 property var components; \n\
                 property var cardData; \n\
                 property var artShapeBorderSource: undefined; \n\
@@ -317,12 +335,12 @@ function cardString(template, components) {
                 property bool asynchronous: true; \n\
                 property bool showHeader: true; \n\
                 implicitWidth: childrenRect.width; \n\
-                enabled: root.template == null ? true : (root.template["non-interactive"] !== undefined ? !root.template["non-interactive"] : true); \n\
-                \n';
+                enabled: %1; \n\
+                \n'.arg(templateInteractive);
 
     var hasArt = components["art"] && components["art"]["field"] || false;
     var hasSummary = components["summary"] || false;
-    var artAndSummary = hasArt && hasSummary;
+    var artAndSummary = hasArt && hasSummary && components["art"]["conciergeMode"] !== true;
     var isHorizontal = template["card-layout"] === "horizontal";
     var hasBackground = (!isHorizontal && (template["card-background"] || components["background"] || artAndSummary)) ||
                         (hasSummary && (template["card-background"] || components["background"]));
@@ -335,7 +353,18 @@ function cardString(template, components) {
     var hasAttributes = hasTitle && components["attributes"]["field"] || false;
 
     if (hasBackground) {
-        code += kBackgroundLoaderCode;
+        var templateCardBackground = (template && typeof template["card-background"] === "string") ? template["card-background"] :  "";
+        var backgroundElements0;
+        var backgroundElements1;
+        if (template && typeof template["card-background"] === "object" && (template["card-background"]["type"] === "color" || template["card-background"]["type"] === "gradient"))  {
+            if (template["card-background"]["elements"][0] !== undefined) {
+                backgroundElements0 = '"%1"'.arg(template["card-background"]["elements"][0]);
+            }
+            if (template["card-background"]["elements"][1] !== undefined) {
+                backgroundElements1 = '"%1"'.arg(template["card-background"]["elements"][1]);
+            }
+        }
+        code += kBackgroundLoaderCode.arg(templateCardBackground).arg(backgroundElements0).arg(backgroundElements1);
     }
 
     if (hasArt) {
@@ -362,6 +391,10 @@ function cardString(template, components) {
         }
 
         code += kArtShapeHolderCode.arg(artAnchors).arg(widthCode).arg(heightCode);
+        var fallback = components["art"] && components["art"]["fallback"] || "";
+        if (fallback !== "") {
+            code += 'Connections { target: artShapeLoader.item ? artShapeLoader.item.image : null; onStatusChanged: if (artShapeLoader.item.image.status === Image.Error) artShapeLoader.item.image.source = "%1"; } \n'.arg(fallback);
+        }
     } else {
         code += 'readonly property size artShapeSize: Qt.size(-1, -1);\n'
     }
@@ -441,6 +474,10 @@ function cardString(template, components) {
 
         var mascotImageVisible = useMascotShape ? 'false' : 'showHeader';
         mascotCode = kMascotImageCode.arg(mascotAnchors).arg(mascotImageVisible);
+        var fallback = components["mascot"] && components["mascot"]["fallback"] || "";
+        if (fallback !== "") {
+            code += 'Connections { target: mascotImage; onStatusChanged: if (mascotImage.status === Image.Error) mascotImage.source = "%1"; } \n'.arg(fallback);
+        }
     }
 
     var summaryColorWithBackground = 'backgroundLoader.active && backgroundLoader.item && root.scopeStyle ? root.scopeStyle.getTextColor(backgroundLoader.item.luminance) : (backgroundLoader.item && backgroundLoader.item.luminance > 0.7 ? Theme.palette.normal.baseText : "white")';
@@ -464,6 +501,7 @@ function cardString(template, components) {
         var attributesAnchors;
         var titleContainerAnchors;
         var titleRightAnchor;
+        var titleWidth = "undefined";
 
         var extraRightAnchor = '';
         var extraLeftAnchor = '';
@@ -507,8 +545,9 @@ function cardString(template, components) {
                 attributesAnchors = subtitleAnchors + 'top: titleLabel.bottom;\n';
             }
         } else if (hasMascot) {
-            // Using row + titleContainer
+            // Using row without titleContainer
             titleAnchors = 'verticalCenter: parent.verticalCenter;\n';
+            titleWidth = "parent.width - x";
         } else {
             if (headerAsOverlay) {
                 // Using anchors to the overlay
@@ -546,7 +585,7 @@ function cardString(template, components) {
 
         // code for different elements
         var titleLabelVisibleExtra = (headerAsOverlay ? '&& overlayLoader.active': '');
-        var titleCode = kTitleLabelCode.arg(titleAnchors).arg(titleColor).arg(titleLabelVisibleExtra);
+        var titleCode = kTitleLabelCode.arg(titleAnchors).arg(titleColor).arg(titleLabelVisibleExtra).arg(titleWidth);
         var subtitleCode;
         var attributesCode;
 
@@ -631,6 +670,8 @@ function cardString(template, components) {
     var implicitHeight = 'implicitHeight: ';
     if (hasSummary) {
         implicitHeight += 'summary.y + summary.height + units.gu(1);\n';
+    } else if (headerAsOverlay) {
+        implicitHeight += 'artShapeHolder.height;\n';
     } else if (hasHeaderRow) {
         implicitHeight += 'row.y + row.height + units.gu(1);\n';
     } else if (hasMascot) {
