@@ -32,21 +32,26 @@ class UNITYINDICATORS_EXPORT IndicatorsManager : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(bool loaded READ isLoaded NOTIFY loadedChanged)
+    Q_PROPERTY(QString profile READ profile WRITE setProfile NOTIFY profileChanged)
 public:
     explicit IndicatorsManager(QObject* parent = 0);
     ~IndicatorsManager();
 
-    Q_INVOKABLE void load(const QString& profile);
+    Q_INVOKABLE void load();
     Q_INVOKABLE void unload();
 
+    QString profile() const;
+    void setProfile(const QString& profile);
+
     Indicator::Ptr indicator(const QString& indicator_name);
 
-    QList<Indicator::Ptr> indicators();
+    QVector<Indicator::Ptr> indicators();
 
     bool isLoaded() const;
 
 Q_SIGNALS:
     void loadedChanged(bool);
+    void profileChanged(const QString&);
 
     void indicatorLoaded(const QString& indicator_name);
     void indicatorAboutToBeUnloaded(const QString& indicator_name);
