@@ -22,12 +22,12 @@
 
 #include <QtQml/QQmlExtensionPlugin>
 
-class Indicators2Plugin : public QQmlExtensionPlugin
+class IndicatorsPlugin : public QQmlExtensionPlugin
 {
     Q_OBJECT
     Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface")
 public:
-    void registerTypes(const char *uri);
+    void registerTypes(const char *uri) override;
 };
 
 #endif // INDICATORS2_PLUGIN_H
