@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 Canonical Ltd.
+ * Copyright 2013-2014 Canonical Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -28,6 +28,7 @@
 class LauncherItem;
 class GSettings;
 class DBusInterface;
+class ASAdapter;
 
 using namespace unity::shell::launcher;
 using namespace unity::shell::application;
@@ -40,33 +41,40 @@ public:
     LauncherModel(QObject *parent = 0);
     ~LauncherModel();
 
-    int rowCount(const QModelIndex &parent = QModelIndex()) const;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
 
-    QVariant data(const QModelIndex &index, int role) const;
+    QVariant data(const QModelIndex &index, int role) const override;
 
-    Q_INVOKABLE unity::shell::launcher::LauncherItemInterface* get(int index) const;
-    Q_INVOKABLE void move(int oldIndex, int newIndex);
-    Q_INVOKABLE void pin(const QString &appId, int index = -1);
-    Q_INVOKABLE void quickListActionInvoked(const QString &appId, int actionIndex);
-    Q_INVOKABLE void setUser(const QString &username);
+    Q_INVOKABLE void setAlerting(const QString &appId, bool alerting) override;
+    Q_INVOKABLE unity::shell::launcher::LauncherItemInterface* get(int index) const override;
+    Q_INVOKABLE void move(int oldIndex, int newIndex) override;
+    Q_INVOKABLE void pin(const QString &appId, int index = -1) override;
+    Q_INVOKABLE void quickListActionInvoked(const QString &appId, int actionIndex) override;
+    Q_INVOKABLE void setUser(const QString &username) override;
     Q_INVOKABLE QString getUrlForAppId(const QString &appId) const;
 
-    unity::shell::application::ApplicationManagerInterface* applicationManager() const;
-    void setApplicationManager(unity::shell::application::ApplicationManagerInterface *appManager);
+    unity::shell::application::ApplicationManagerInterface* applicationManager() const override;
+    void setApplicationManager(unity::shell::application::ApplicationManagerInterface *appManager) override;
+
+    bool onlyPinned() const override;
+    void setOnlyPinned(bool onlyPinned) override;
 
     int findApplication(const QString &appId);
 
 public Q_SLOTS:
-    void requestRemove(const QString &appId);
+    void requestRemove(const QString &appId) override;
+    Q_INVOKABLE void refresh();
+    Q_INVOKABLE void alert(const QString &appId);
 
 private:
     void storeAppList();
 
+    void unpin(const QString &appId);
+
 private Q_SLOTS:
     void countChanged(const QString &appId, int count);
-    void countVisibleChanged(const QString &appId, int count);
+    void countVisibleChanged(const QString &appId, bool count);
     void progressChanged(const QString &appId, int progress);
-    void refresh();
 
     void applicationAdded(const QModelIndex &parent, int row);
     void applicationRemoved(const QModelIndex &parent, int row);
@@ -77,8 +85,11 @@ private:
 
     GSettings *m_settings;
     DBusInterface *m_dbusIface;
+    ASAdapter *m_asAdapter;
 
     ApplicationManagerInterface *m_appManager;
+
+    friend class LauncherModelTest;
 };
 
 #endif // LAUNCHERMODEL_H
