@@ -104,10 +104,10 @@ bool MouseTouchAdaptor::handleButtonPress(xcb_button_press_event_t *pressEvent)
     if (button != Qt::LeftButton)
         return true;
 
-    QPoint windowPos(pressEvent->event_x, pressEvent->event_y);
-
     QWindow *targetWindow = findQWindowWithXWindowID(static_cast<WId>(pressEvent->event));
 
+    QPoint windowPos(pressEvent->event_x / targetWindow->devicePixelRatio(), pressEvent->event_y / targetWindow->devicePixelRatio());
+
     QTouchEventSequence touchEvent = QTest::touchEvent(targetWindow, m_touchDevice,
                                                        false /* autoCommit */);
     touchEvent.press(0 /* touchId */, windowPos);
@@ -125,10 +125,10 @@ bool MouseTouchAdaptor::handleButtonRelease(xcb_button_release_event_t *releaseE
     if (button != Qt::LeftButton)
         return true;
 
-    QPoint windowPos(releaseEvent->event_x, releaseEvent->event_y);
-
     QWindow *targetWindow = findQWindowWithXWindowID(static_cast<WId>(releaseEvent->event));
 
+    QPoint windowPos(releaseEvent->event_x / targetWindow->devicePixelRatio(), releaseEvent->event_y / targetWindow->devicePixelRatio());
+
     QTouchEventSequence touchEvent = QTest::touchEvent(targetWindow, m_touchDevice,
                                                        false /* autoCommit */);
     touchEvent.release(0 /* touchId */, windowPos);
@@ -144,10 +144,10 @@ bool MouseTouchAdaptor::handleMotionNotify(xcb_motion_notify_event_t *event)
         return true;
     }
 
-    QPoint windowPos(event->event_x, event->event_y);
-
     QWindow *targetWindow = findQWindowWithXWindowID(static_cast<WId>(event->event));
 
+    QPoint windowPos(event->event_x / targetWindow->devicePixelRatio(), event->event_y / targetWindow->devicePixelRatio());
+
     QTouchEventSequence touchEvent = QTest::touchEvent(targetWindow, m_touchDevice,
                                                        false /* autoCommit */);
     touchEvent.move(0 /* touchId */, windowPos);
