@@ -1,7 +1,7 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #
 # Unity Autopilot Test Suite
-# Copyright (C) 2012, 2013, 2014 Canonical
+# Copyright (C) 2012, 2013, 2014, 2015 Canonical
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,35 +19,30 @@
 
 """Tests for Notifications"""
 
-from __future__ import absolute_import
-
-from unity8 import shell
-from unity8.process_helpers import unlock_unity
-from unity8.shell.tests import UnityTestCase, _get_device_emulation_scenarios
-
-from testtools.matchers import Equals, NotEquals
-from autopilot.matchers import Eventually
-
-from gi.repository import Notify
 import time
 import os
 import logging
 import signal
 import subprocess
-import sys
+
+from autopilot.matchers import Eventually
+from gi.repository import Notify
+from testtools.matchers import Equals, NotEquals
+from ubuntuuitoolkit import ubuntu_scenarios
+
+from unity8 import shell
+from unity8.process_helpers import unlock_unity
+from unity8.shell.tests import UnityTestCase
+
 
 logger = logging.getLogger(__name__)
 
-# from __future__ import range
-# (python3's range, is same as python2's xrange)
-if sys.version_info < (3,):
-    range = xrange
-
 
 class NotificationsBase(UnityTestCase):
     """Base class for all notification tests that provides helper methods."""
 
-    scenarios = _get_device_emulation_scenarios('Nexus4')
+    scenarios = ubuntu_scenarios.get_device_simulation_scenarios(
+        ubuntu_scenarios.NEXUS4_DEVICE)
 
     def _get_icon_path(self, icon_name):
         """Given an icons file name returns the full path (either system or
@@ -118,14 +113,14 @@ class InteractiveNotificationBase(NotificationsBase):
     """Collection of test for Interactive tests including snap decisions."""
 
     def setUp(self):
-        super(InteractiveNotificationBase, self).setUp()
+        super().setUp()
         # Need to keep track when we launch the notification script.
         self._notify_proc = None
 
     def test_interactive(self):
         """Interactive notification must react upon click on itself."""
-        unity_proxy = self.launch_unity()
-        unlock_unity(unity_proxy)
+        self.launch_unity()
+        unlock_unity()
 
         notify_list = self._get_notifications_list()
 
@@ -135,7 +130,7 @@ class InteractiveNotificationBase(NotificationsBase):
         actions = [("action_id", "dummy")]
         hints = [
             ("x-canonical-switch-to-application", "true"),
-            ("x-canonical-secondary-icon","dialer")
+            ("x-canonical-secondary-icon", "dialer")
         ]
 
         self._create_interactive_notification(
@@ -157,61 +152,12 @@ class InteractiveNotificationBase(NotificationsBase):
 
         self.assert_notification_action_id_was_called('action_id')
 
-    def test_sd_incoming_call(self):
-        """Rejecting a call should make notification expand and
-            offer more options."""
-        unity_proxy = self.launch_unity()
-        unlock_unity(unity_proxy)
-
-        summary = "Incoming call"
-        body = "Frank Zappa\n+44 (0)7736 027340"
-        icon_path = self._get_icon_path('avatars/anna_olsson.png')
-        hints = [
-            ("x-canonical-secondary-icon", "incoming-call"),
-            ("x-canonical-snap-decisions", "true"),
-            ("x-canonical-private-affirmative-tint", "true"),
-            ("x-canonical-private-rejection-tint", "true"),
-        ]
-
-        actions = [
-            ('action_accept', 'Hold + Answer'),
-            ('action_decline_1', 'End + Answer'),
-            ('action_decline_2', 'Decline'),
-            ('action_decline_3', 'message:I missed your call - can you call me now?'),
-            ('action_decline_4', 'message:I\'m running late. I\'m on my way.'),
-            ('action_decline_5', 'message:I\'m busy at the moment. I\'ll call later.'),
-            ('action_decline_6', 'edit:Custom'),
-        ]
-
-        self._create_interactive_notification(
-            summary,
-            body,
-            icon_path,
-            "NORMAL",
-            actions,
-            hints
-        )
-
-        notify_list = self._get_notifications_list()
-        get_notification = lambda: notify_list.wait_select_single(
-            'Notification', objectName='notification1')
-        notification = get_notification()
-        self._assert_notification(notification, summary, body, True, True, 1.0)
-        notification.pointing_device.click_object(
-            notification.select_single(objectName="combobutton_dropdown"))
-        self.assertThat(
-            notification.select_single(objectName="notify_button2").expanded,
-            Eventually(Equals(True)))
-        time.sleep(2)
-        notification.pointing_device.click_object(
-            notification.select_single(objectName="notify_button4"))
-        self.assert_notification_action_id_was_called("action_decline_4")
-
-
     def test_sd_one_over_two_layout(self):
-        """Snap-decision with three actions should use one-over two button layout."""
-        unity_proxy = self.launch_unity()
-        unlock_unity(unity_proxy)
+        """Snap-decision with three actions should use
+           one-over two button layout.
+        """
+        self.launch_unity()
+        unlock_unity()
 
         summary = "Theatre at Ferria Stadium"
         body = "at Ferria Stadium in Bilbao, Spain\n07578545317"
@@ -248,9 +194,11 @@ class InteractiveNotificationBase(NotificationsBase):
         self.assert_notification_action_id_was_called("action_accept")
 
     def test_modal_sd_without_greeter(self):
-        """Snap-decision should block input to shell without greeter."""
-        unity_proxy = self.launch_unity()
-        unlock_unity(unity_proxy)
+        """Snap-decision should block input to shell
+           without greeter/lockscreen.
+        """
+        self.launch_unity()
+        unlock_unity()
 
         summary = "Incoming file"
         body = "Frank would like to send you the file: essay.pdf"
@@ -295,7 +243,9 @@ class InteractiveNotificationBase(NotificationsBase):
         self.assert_notification_action_id_was_called("action_accept")
 
     def test_modal_sd_with_greeter(self):
-        """A snap-decision should not block input to the greeter beneath it."""
+        """A snap-decision should block input to the
+           greeter/lockscreen beneath it.
+        """
         self.launch_unity()
 
         summary = "Incoming file"
@@ -322,11 +272,12 @@ class InteractiveNotificationBase(NotificationsBase):
             hints
         )
 
-        # verify that we can swipe away the greeter (interact with the "shell")
+        # verify that we cannot reveal the launcher (no longer interact with
+        # the shell)
         time.sleep(1)
         self.main_window.show_dash_swiping()
-        greeter = self.main_window.get_greeter()
-        self.assertThat(greeter.shown, Eventually(Equals(False)))
+        self.assertThat(
+            self.main_window.is_launcher_open, Eventually(Equals(False)))
 
         # verify and interact with the triggered snap-decision notification
         notify_list = self._get_notifications_list()
@@ -388,7 +339,7 @@ class InteractiveNotificationBase(NotificationsBase):
             action_string = "%s,%s" % (action_id, action_label)
             script_args.extend(['--action', action_string])
 
-        python_bin = subprocess.check_output(['which', 'python']).strip()
+        python_bin = subprocess.check_output(['which', 'python3']).strip()
         command = [python_bin, self._get_notify_script()] + script_args
         logger.info("Launching snap-decision notification as: %s", command)
         self._notify_proc = subprocess.Popen(
@@ -408,8 +359,10 @@ class InteractiveNotificationBase(NotificationsBase):
             raise RuntimeError("Call to script failed with: %s" % error_output)
 
     def _get_notify_script(self):
-        """Returns the path to the interactive notification creation script."""
-        file_path = "../../emulators/create_interactive_notification.py"
+        """Returns the path to the interactive notification
+           creation script.
+        """
+        file_path = "../../create_interactive_notification.py"
 
         the_path = os.path.abspath(
             os.path.join(__file__, file_path))
@@ -460,7 +413,7 @@ class EphemeralNotificationsTests(NotificationsBase):
     """Collection of tests for Emphemeral notifications (non-interactive.)"""
 
     def setUp(self):
-        super(EphemeralNotificationsTests, self).setUp()
+        super().setUp()
         # Because we are using the Notify library we need to init and un-init
         # otherwise we get crashes.
         Notify.init("Autopilot Ephemeral Notification Tests")
@@ -468,8 +421,8 @@ class EphemeralNotificationsTests(NotificationsBase):
 
     def test_icon_summary_body(self):
         """Notification must display the expected summary and body text."""
-        unity_proxy = self.launch_unity()
-        unlock_unity(unity_proxy)
+        self.launch_unity()
+        unlock_unity()
 
         notify_list = self._get_notifications_list()
 
@@ -505,14 +458,14 @@ class EphemeralNotificationsTests(NotificationsBase):
     def test_icon_summary(self):
         """Notification must display the expected summary and secondary
         icon."""
-        unity_proxy = self.launch_unity()
-        unlock_unity(unity_proxy)
+        self.launch_unity()
+        unlock_unity()
 
         notify_list = self._get_notifications_list()
 
         summary = "Upload of image completed"
         icon_path = self._get_icon_path('applicationIcons/facebook.png')
-        hints=[]
+        hints = []
 
         notification = shell.create_ephemeral_notification(
             summary,
@@ -538,8 +491,8 @@ class EphemeralNotificationsTests(NotificationsBase):
     def test_urgency_order(self):
         """Notifications must be displayed in order according to their
         urgency."""
-        unity_proxy = self.launch_unity()
-        unlock_unity(unity_proxy)
+        self.launch_unity()
+        unlock_unity()
 
         notify_list = self._get_notifications_list()
 
@@ -625,8 +578,8 @@ class EphemeralNotificationsTests(NotificationsBase):
 
     def test_summary_and_body(self):
         """Notification must display the expected summary- and body-text."""
-        unity_proxy = self.launch_unity()
-        unlock_unity(unity_proxy)
+        self.launch_unity()
+        unlock_unity()
 
         notify_list = self._get_notifications_list()
 
@@ -650,8 +603,8 @@ class EphemeralNotificationsTests(NotificationsBase):
 
     def test_summary_only(self):
         """Notification must display only the expected summary-text."""
-        unity_proxy = self.launch_unity()
-        unlock_unity(unity_proxy)
+        self.launch_unity()
+        unlock_unity()
 
         notify_list = self._get_notifications_list()
 
@@ -668,8 +621,8 @@ class EphemeralNotificationsTests(NotificationsBase):
     def test_update_notification_same_layout(self):
         """Notification must allow updating its contents while being
         displayed."""
-        unity_proxy = self.launch_unity()
-        unlock_unity(unity_proxy)
+        self.launch_unity()
+        unlock_unity()
 
         notify_list = self._get_notifications_list()
 
@@ -707,8 +660,8 @@ class EphemeralNotificationsTests(NotificationsBase):
     def test_update_notification_layout_change(self):
         """Notification must allow updating its contents and layout while
         being displayed."""
-        unity_proxy = self.launch_unity()
-        unlock_unity(unity_proxy)
+        self.launch_unity()
+        unlock_unity()
 
         notify_list = self._get_notifications_list()
 
@@ -751,3 +704,22 @@ class EphemeralNotificationsTests(NotificationsBase):
         self.assertThat(get_notification, Eventually(NotEquals(None)))
         self._assert_notification(
             get_notification(), summary, body, False, False, 1.0)
+
+    def test_notification_helper(self):
+        """ use the create notification script to get a notification dialog.
+        Check that the arguments passed to the script match the fields. """
+
+        self.launch_unity()
+        unlock_unity()
+
+        summary = 'Helper summary'
+        body = 'Helper body'
+
+        notification = shell.create_ephemeral_notification(summary, body)
+        notification.show()
+
+        notification_data = self.main_window.wait_for_notification()
+
+        self.assertThat(notification_data['summary'],
+                        Eventually(Equals(summary)))
+        self.assertThat(notification_data['body'], Eventually(Equals(body)))
