@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2014 Canonical, Ltd.
+ * Copyright (C) 2013-2015 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,8 +49,6 @@ ApplicationManager *ApplicationManager::singleton()
 
 ApplicationManager::ApplicationManager(QObject *parent)
     : ApplicationManagerInterface(parent)
-    , m_suspended(false)
-    , m_forceDashActive(false)
 {
     m_roleNames.insert(RoleSession, "session");
     m_roleNames.insert(RoleFullscreen, "fullscreen");
@@ -143,7 +141,7 @@ QModelIndex ApplicationManager::findIndex(ApplicationInfo* application)
 }
 
 void ApplicationManager::add(ApplicationInfo *application) {
-    if (!application) {
+    if (!application || m_runningApplications.contains(application)) {
         return;
     }
 
@@ -217,7 +215,7 @@ ApplicationInfo* ApplicationManager::startApplication(const QString &appId,
             && application->stage() == ApplicationInfo::SideStage) {
         application->setStage(ApplicationInfo::MainStage);
     }
-    application->setState(ApplicationInfo::Running);
+    application->setState(ApplicationInfo::Starting);
 
     return application;
 }
@@ -262,50 +260,6 @@ QString ApplicationManager::focusedApplicationId() const {
     return QString();
 }
 
-bool ApplicationManager::suspended() const
-{
-    return m_suspended;
-}
-
-void ApplicationManager::setSuspended(bool suspended)
-{
-    ApplicationInfo *focusedApp = findApplication(focusedApplicationId());
-    if (focusedApp) {
-        if (suspended) {
-            focusedApp->setState(ApplicationInfo::Suspended);
-        } else {
-            focusedApp->setState(ApplicationInfo::Running);
-        }
-    }
-    m_suspended = suspended;
-    Q_EMIT suspendedChanged();
-}
-
-bool ApplicationManager::forceDashActive() const
-{
-    return m_forceDashActive;
-}
-
-void ApplicationManager::setForceDashActive(bool forceDashActive)
-{
-    if (m_forceDashActive == forceDashActive) {
-        return;
-    }
-
-    ApplicationInfo *dash = findApplication("unity8-dash");
-    if (dash) {
-        if (forceDashActive) {
-            dash->setState(ApplicationInfo::Running);
-        } else {
-            if (!dash->focused()) {
-                dash->setState(ApplicationInfo::Suspended);
-            }
-        }
-    }
-    m_forceDashActive = forceDashActive;
-    Q_EMIT forceDashActiveChanged();
-}
-
 bool ApplicationManager::focusApplication(const QString &appId)
 {
     ApplicationInfo *application = findApplication(appId);
@@ -316,13 +270,11 @@ bool ApplicationManager::focusApplication(const QString &appId)
     for (ApplicationInfo *app : m_runningApplications) {
         if (app->focused()) {
             app->setFocused(false);
-            app->setState(ApplicationInfo::Suspended);
         }
     }
 
     // focus this app
     application->setFocused(true);
-    application->setState(ApplicationInfo::Running);
 
     // move app to top of stack
     move(m_runningApplications.indexOf(application), 0);
@@ -348,6 +300,13 @@ void ApplicationManager::unfocusCurrentApplication()
 
 void ApplicationManager::buildListOfAvailableApplications()
 {
+    /*
+        ATTENTION!
+        Be careful when changing application properties here as some qmltests
+        rely on them being the way it's specified here (e.g. that camera-app
+        is fullscreen, that twitter-webapp can rotate in all directions, etc)
+     */
+
     ApplicationInfo *application;
 
     application = new ApplicationInfo(this);
@@ -355,6 +314,7 @@ void ApplicationManager::buildListOfAvailableApplications()
     application->setName("Unity 8 Mock Dash");
     application->setScreenshotId("unity8-dash");
     application->setStage(ApplicationInfo::MainStage);
+    application->setSupportedOrientations(Qt::PrimaryOrientation);
     m_availableApplications.append(application);
 
     application = new ApplicationInfo(this);
@@ -363,6 +323,8 @@ void ApplicationManager::buildListOfAvailableApplications()
     application->setScreenshotId("dialer");
     application->setIconId("dialer-app");
     application->setStage(ApplicationInfo::SideStage);
+    application->setSupportedOrientations(Qt::PortraitOrientation
+                                        | Qt::InvertedPortraitOrientation);
     m_availableApplications.append(application);
 
     application = new ApplicationInfo(this);
@@ -371,6 +333,11 @@ void ApplicationManager::buildListOfAvailableApplications()
     application->setScreenshotId("camera");
     application->setIconId("camera");
     application->setFullscreen(true);
+    application->setSupportedOrientations(Qt::PortraitOrientation
+                                        | Qt::LandscapeOrientation
+                                        | Qt::InvertedPortraitOrientation
+                                        | Qt::InvertedLandscapeOrientation);
+    application->setRotatesWindowContents(true);
     m_availableApplications.append(application);
 
     application = new ApplicationInfo(this);
@@ -379,6 +346,7 @@ void ApplicationManager::buildListOfAvailableApplications()
     application->setScreenshotId("gallery");
     application->setIconId("gallery");
     application->setFullscreen(true);
+    application->setStage(ApplicationInfo::MainStage);
     m_availableApplications.append(application);
 
     application = new ApplicationInfo(this);
@@ -416,13 +384,35 @@ void ApplicationManager::buildListOfAvailableApplications()
     application->setAppId("gmail-webapp");
     application->setName("GMail");
     application->setIconId("gmail");
+    application->setScreenshotId("gmail-webapp.svg");
+    application->setFullscreen(false);
+    application->setStage(ApplicationInfo::MainStage);
+    application->setSupportedOrientations(Qt::PortraitOrientation
+                                        | Qt::LandscapeOrientation
+                                        | Qt::InvertedPortraitOrientation
+                                        | Qt::InvertedLandscapeOrientation);
+    m_availableApplications.append(application);
+
+    application = new ApplicationInfo(this);
+    application->setAppId("music-app");
+    application->setName("Music");
+    application->setIconId("soundcloud");
+    application->setScreenshotId("music");
+    application->setFullscreen(false);
+    application->setStage(ApplicationInfo::MainStage);
+    application->setSupportedOrientations(Qt::PortraitOrientation
+                                        | Qt::LandscapeOrientation
+                                        | Qt::InvertedPortraitOrientation
+                                        | Qt::InvertedLandscapeOrientation);
     m_availableApplications.append(application);
 
     application = new ApplicationInfo(this);
     application->setAppId("ubuntu-weather-app");
     application->setName("Weather");
     application->setIconId("weather");
-    application->setStage(ApplicationInfo::SideStage);
+    application->setScreenshotId("ubuntu-weather-app.svg");
+    application->setSupportedOrientations(Qt::LandscapeOrientation
+                                        | Qt::InvertedLandscapeOrientation);
     m_availableApplications.append(application);
 
     application = new ApplicationInfo(this);
