@@ -1,5 +1,5 @@
 /*
- * Copyright 2013-2014 Canonical Ltd.
+ * Copyright 2013-2015 Canonical Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -39,19 +39,24 @@ class MockApp: public unity::shell::application::ApplicationInfoInterface
     Q_OBJECT
 public:
     MockApp(const QString &appId, QObject *parent = 0): ApplicationInfoInterface(appId, parent), m_appId(appId), m_focused(false) { }
-    QString appId() const { return m_appId; }
-    QString name() const { return "mock"; }
-    QString comment() const { return "this is a mock"; }
-    QUrl icon() const { return QUrl(); }
-    ApplicationInfoInterface::Stage stage() const { return ApplicationInfoInterface::MainStage; }
-    ApplicationInfoInterface::State state() const { return ApplicationInfoInterface::Running; }
-    bool focused() const { return m_focused; }
+
+    RequestedState requestedState() const override { return RequestedRunning; }
+    void setRequestedState(RequestedState) override {}
+    QString appId() const override { return m_appId; }
+    QString name() const override { return "mock"; }
+    QString comment() const override { return "this is a mock"; }
+    QUrl icon() const override { return QUrl(); }
+    ApplicationInfoInterface::Stage stage() const override { return ApplicationInfoInterface::MainStage; }
+    ApplicationInfoInterface::State state() const override { return ApplicationInfoInterface::Running; }
+    bool focused() const override { return m_focused; }
     QString splashTitle() const override { return QString(); }
     QUrl splashImage() const override { return QUrl(); }
     bool splashShowHeader() const override { return true; }
     QColor splashColor() const override { return QColor(0,0,0,0); }
     QColor splashColorHeader() const override { return QColor(0,0,0,0); }
     QColor splashColorFooter() const override { return QColor(0,0,0,0); }
+    Qt::ScreenOrientations supportedOrientations() const override { return Qt::PortraitOrientation; }
+    bool rotatesWindowContents() const override { return false; }
 
     // Methods used for mocking (not in the interface)
     void setFocused(bool focused) { m_focused = focused; Q_EMIT focusedChanged(focused); }
@@ -66,16 +71,17 @@ class MockAppManager: public unity::shell::application::ApplicationManagerInterf
     Q_OBJECT
 public:
     MockAppManager(QObject *parent = 0): ApplicationManagerInterface(parent) {}
-    int rowCount(const QModelIndex &) const { return m_list.count(); }
-    QVariant data(const QModelIndex &, int ) const { return QVariant(); }
-    QString focusedApplicationId() const {
+    ~MockAppManager() {}
+    int rowCount(const QModelIndex &) const override { return m_list.count(); }
+    QVariant data(const QModelIndex &, int ) const override { return QVariant(); }
+    QString focusedApplicationId() const override {
         Q_FOREACH(MockApp *app, m_list) {
             if (app->focused()) return app->appId();
         }
         return QString();
     }
-    unity::shell::application::ApplicationInfoInterface *get(int index) const { return m_list.at(index); }
-    unity::shell::application::ApplicationInfoInterface *findApplication(const QString &appId) const {
+    unity::shell::application::ApplicationInfoInterface *get(int index) const override { return m_list.at(index); }
+    unity::shell::application::ApplicationInfoInterface *findApplication(const QString &appId) const override {
         Q_FOREACH(MockApp* app, m_list) {
             if (app->appId() == appId) {
                 return app;
@@ -83,8 +89,8 @@ public:
         }
         return nullptr;
     }
-    unity::shell::application::ApplicationInfoInterface *startApplication(const QString &, const QStringList &) { return nullptr; }
-    bool stopApplication(const QString &appId) {
+    unity::shell::application::ApplicationInfoInterface *startApplication(const QString &, const QStringList &) override { return nullptr; }
+    bool stopApplication(const QString &appId) override {
         Q_FOREACH(MockApp* app, m_list) {
             if (app->appId() == appId) {
                 removeApplication(m_list.indexOf(app));
@@ -93,7 +99,7 @@ public:
         }
         return false;
     }
-    bool focusApplication(const QString &appId) {
+    bool focusApplication(const QString &appId) override {
         Q_FOREACH(MockApp* app, m_list) {
             app->setFocused(app->appId() == appId);
         }
@@ -101,7 +107,7 @@ public:
         return true;
     }
 
-    void unfocusCurrentApplication() { }
+    void unfocusCurrentApplication() override { }
 
     void addApplication(MockApp *app) {
         beginInsertRows(QModelIndex(), count(), count());
@@ -113,11 +119,7 @@ public:
         m_list.takeAt(index)->deleteLater();
         endRemoveRows();
     }
-    bool requestFocusApplication(const QString &appId) { Q_UNUSED(appId); return true; }
-    bool suspended() const { return false; }
-    void setSuspended(bool) {}
-    bool forceDashActive() const { return false; }
-    void setForceDashActive(bool) {}
+    bool requestFocusApplication(const QString &appId) override { Q_UNUSED(appId); return true; }
 
 private:
     QList<MockApp*> m_list;
@@ -185,7 +187,7 @@ private Q_SLOTS:
     }
 
     void testPinning() {
-        QSignalSpy spy(launcherModel, SIGNAL(dataChanged(QModelIndex,QModelIndex,QVector<int>)));
+        QSignalSpy spy(launcherModel, &LauncherModel::dataChanged);
         QCOMPARE(launcherModel->get(0)->pinned(), false);
         QCOMPARE(launcherModel->get(1)->pinned(), false);
         launcherModel->pin(launcherModel->get(0)->appId());
@@ -296,6 +298,22 @@ private Q_SLOTS:
         QCOMPARE(launcherModel->rowCount(QModelIndex()), 1);
     }
 
+    void testApplicationRunning() {
+        launcherModel->pin("abs-icon");
+        launcherModel->pin("no-icon");
+
+        QCOMPARE(launcherModel->get(0)->running(), true);
+        QCOMPARE(launcherModel->get(1)->running(), true);
+
+        appManager->stopApplication("abs-icon");
+        QCOMPARE(launcherModel->get(0)->running(), false);
+        QCOMPARE(launcherModel->get(1)->running(), true);
+
+        appManager->stopApplication("no-icon");
+        QCOMPARE(launcherModel->get(0)->running(), false);
+        QCOMPARE(launcherModel->get(1)->running(), false);
+    }
+
     void testApplicationFocused() {
         // all apps unfocused at beginning...
         QCOMPARE(launcherModel->get(0)->focused(), false);
@@ -323,6 +341,46 @@ private Q_SLOTS:
         QCOMPARE(launcherModel->get(0)->appId(), QLatin1String("abs-icon"));
     }
 
+    void testQuitMenuItem() {
+        // we have 2 apps running, both should have the Quit action in its quick list
+        QCOMPARE(launcherModel->rowCount(), 2);
+
+        // stop the second one keeping it pinned so that it doesn't go away
+        launcherModel->pin("no-icon");
+        appManager->stopApplication("no-icon");
+
+        // find the first Quit item, should be there
+        QuickListModel *model = qobject_cast<QuickListModel*>(launcherModel->get(0)->quickList());
+        int quitActionIndex = -1;
+        for (int i = 0; i < model->rowCount(); ++i) {
+            if (model->get(i).actionId() == "stop_item") {
+                quitActionIndex = i;
+                break;
+            }
+        }
+        QVERIFY(quitActionIndex >= 0);
+
+        // find the second Quit item, should NOT be there, the app is stopped
+        QuickListModel *model2 = qobject_cast<QuickListModel*>(launcherModel->get(1)->quickList());
+        int quitActionIndex2 = -1;
+        for (int i = 0; i < model2->rowCount(); ++i) {
+            if (model2->get(i).actionId() == "stop_item") {
+                quitActionIndex2 = i;
+                break;
+            }
+        }
+        QVERIFY(quitActionIndex2 == -1);
+
+        // trigger the first quit item quicklist action
+        launcherModel->quickListActionInvoked(launcherModel->get(0)->appId(), quitActionIndex);
+        // first app should be gone...
+        QCOMPARE(launcherModel->rowCount(QModelIndex()), 1);
+        // ... the second app (now at index 0) should still be there, pinned and stopped
+        QCOMPARE(launcherModel->get(0)->appId(), QStringLiteral("no-icon"));
+        QCOMPARE(launcherModel->get(0)->pinned(), true);
+        QCOMPARE(launcherModel->get(0)->running(), false);
+    }
+
     void testGetUrlForAppId() {
         QCOMPARE(launcherModel->getUrlForAppId(QString()), QString());
         QCOMPARE(launcherModel->getUrlForAppId(""), QString());
@@ -366,11 +424,18 @@ private Q_SLOTS:
     }
 
     void testCountEmblems() {
+        QSignalSpy spy(launcherModel, &LauncherModel::dataChanged);
+
         // Call GetAll on abs-icon
         QDBusInterface interface("com.canonical.Unity.Launcher", "/com/canonical/Unity/Launcher/abs_2Dicon", "org.freedesktop.DBus.Properties");
         QDBusReply<QVariantMap> reply = interface.call("GetAll");
         QVariantMap map = reply.value();
 
+        // Check that the alerting-status is still false, and the item on the upper side of the API
+        int index = launcherModel->findApplication("abs-icon");
+        QCOMPARE(index >= 0, true);
+        QVERIFY(launcherModel->get(index)->alerting() == false);
+
         // Make sure GetAll returns a map with count and countVisible props
         QCOMPARE(map.contains("count"), true);
         QCOMPARE(map.contains("countVisible"), true);
@@ -391,13 +456,8 @@ private Q_SLOTS:
         QCOMPARE(map.value("count").toInt(), 55);
         QCOMPARE(map.value("countVisible").toBool(), true);
 
-        // Now the item on the upper side of the API
-        int index = launcherModel->findApplication("abs-icon");
-        QCOMPARE(index >= 0, true);
-
-        // And make sure values have changed there as well
-        QCOMPARE(launcherModel->get(index)->countVisible(), true);
-        QCOMPARE(launcherModel->get(index)->count(), 55);
+        // Finally check, that the change to "count" implicitly also set the alerting-state to true
+        QVERIFY(launcherModel->get(index)->alerting() == true);
     }
 
     void testCountEmblemAddsRemovesItem_data() {
@@ -457,6 +517,20 @@ private Q_SLOTS:
         QCOMPARE(index == -1, !isRunning && !isPinned && !startWhenVisible);
     }
 
+    void testAlert() {
+        // Check that the alerting-status is still false
+        int index = launcherModel->findApplication("abs-icon");
+        QCOMPARE(index >= 0, true);
+        QVERIFY(launcherModel->get(index)->alerting() == false);
+
+        // Call Alert() on "abs-icon"
+        QDBusInterface interface("com.canonical.Unity.Launcher", "/com/canonical/Unity/Launcher/abs_2Dicon", "com.canonical.Unity.Launcher.Item");
+        interface.call("Alert");
+
+        // Check that the alerting-status is now true
+        QVERIFY(launcherModel->get(index)->alerting() == true);
+    }
+
     void testRefreshAfterDeletedDesktopFiles_data() {
         QTest::addColumn<bool>("deleted");
         QTest::newRow("have .desktop files") << false;
@@ -496,7 +570,7 @@ private Q_SLOTS:
 
     void testSettings() {
         GSettings *settings = launcherModel->m_settings;
-        QSignalSpy spy(launcherModel, SIGNAL(hint()));
+        QSignalSpy spy(launcherModel, &LauncherModel::hint);
 
         // Nothing pinned at startup
         QCOMPARE(settings->storedApplications().count(), 0);
